@@ -1,5 +1,5 @@
 /*
- * Copyright 2003-2018  Thomas Baumgart <tbaumgart@kde.org>
+ * Copyright 2003-2019  Thomas Baumgart <tbaumgart@kde.org>
  * Copyright 2004       Ace Jones <acejones@users.sourceforge.net>
  * Copyright 2008-2010  Alvaro Soliverez <asoliverez@gmail.com>
  * Copyright 2017-2018  Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
@@ -329,9 +329,9 @@ QVector<MyMoneySplit> MyMoneyTransactionFilter::matchingSplits(const MyMoneyTran
   auto isMatchingSplitsEmpty = true;
 
   auto extendedFilter = d->m_filterSet;
-  extendedFilter.singleFilter.dateFilter =
-  extendedFilter.singleFilter.accountFilter =
-      extendedFilter.singleFilter.categoryFilter = 0;
+  extendedFilter.singleFilter.dateFilter = 0;
+  extendedFilter.singleFilter.accountFilter = 0;
+  extendedFilter.singleFilter.categoryFilter = 0;
 
   if (filter.accountFilter ||
       filter.categoryFilter ||
@@ -537,7 +537,8 @@ bool MyMoneyTransactionFilter::matchText(const MyMoneySplit& s, const MyMoneyAcc
     if (!s.payeeId().isEmpty() && file->payee(s.payeeId()).name().contains(d->m_text))
       return !d->m_invertText;
 
-    for (const auto& tag : s.tagIdList())
+    const auto& tagIdList = s.tagIdList();
+    for (const auto& tag : tagIdList)
       if (file->tag(tag).name().contains(d->m_text))
         return !d->m_invertText;
 
@@ -616,8 +617,8 @@ int MyMoneyTransactionFilter::splitType(const MyMoneyTransaction& t, const MyMon
 eMyMoney::TransactionFilter::Validity MyMoneyTransactionFilter::validTransaction(const MyMoneyTransaction& t) const
 {
   MyMoneyMoney val;
-
-  for (const auto& split : t.splits())
+  const auto& splits = t.splits();
+  for (const auto& split : splits)
     val += split.value();
 
   return (val == MyMoneyMoney()) ? eMyMoney::TransactionFilter::Validity::Valid : eMyMoney::TransactionFilter::Validity::Invalid;
@@ -762,6 +763,21 @@ bool MyMoneyTransactionFilter::states(QList<int>& list) const
   return result;
 }
 
+bool MyMoneyTransactionFilter::validities(QList<int>& list) const
+{
+  Q_D(const MyMoneyTransactionFilter);
+  auto result = d->m_filterSet.singleFilter.validityFilter;
+
+  if (result) {
+    QHashIterator<int, QString> it_validity(d->m_validity);
+    while (it_validity.hasNext()) {
+      it_validity.next();
+      list += it_validity.key();
+    }
+  }
+  return result;
+}
+
 bool MyMoneyTransactionFilter::firstType(int&i) const
 {
   Q_D(const MyMoneyTransactionFilter);
@@ -792,6 +808,21 @@ bool MyMoneyTransactionFilter::firstState(int&i) const
   return result;
 }
 
+bool MyMoneyTransactionFilter::firstValidity(int&i) const
+{
+  Q_D(const MyMoneyTransactionFilter);
+  auto result = d->m_filterSet.singleFilter.validityFilter;
+
+  if (result) {
+    QHashIterator<int, QString> it_validity(d->m_validity);
+    if (it_validity.hasNext()) {
+      it_validity.next();
+      i = it_validity.key();
+    }
+  }
+  return result;
+}
+
 bool MyMoneyTransactionFilter::textFilter(QRegExp& exp) const
 {
   Q_D(const MyMoneyTransactionFilter);
