@@ -1,6 +1,6 @@
 /*
  * Copyright 2005       Ace Jones acejones@users.sourceforge.net
- * Copyright 2010-2018  Thomas Baumgart tbaumgart@kde.org
+ * Copyright 2010-2019  Thomas Baumgart tbaumgart@kde.org
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -36,6 +36,8 @@
 #include <KActionCollection>
 #include <KLocalizedString>
 #include <KWallet>
+#include <KSharedConfig>
+#include <KConfigGroup>
 
 // ----------------------------------------------------------------------------
 // Project Includes
@@ -58,10 +60,16 @@
 
 using KWallet::Wallet;
 
+typedef enum  {
+  UniqueIdUnknown = -1,
+  UniqueIdOfx = 0,
+  UniqueIdKMyMoney
+} UniqueTransactionIdSource;
+
 class OFXImporter::Private
 {
 public:
-  Private() : m_valid(false), m_preferName(PreferId), m_walletIsOpen(false), m_statusDlg(0), m_wallet(0),
+  Private() : m_valid(false), m_preferName(PreferId), m_uniqueIdSource(UniqueIdUnknown), m_walletIsOpen(false), m_statusDlg(0), m_wallet(0),
               m_updateStartDate(QDate(1900,1,1)), m_timestampOffset(0) {}
 
   bool m_valid;
@@ -70,6 +78,7 @@ public:
     PreferName,
     PreferMemo
   } m_preferName;
+  UniqueTransactionIdSource  m_uniqueIdSource;
   bool m_walletIsOpen;
   QList<MyMoneyStatement> m_statementlist;
   QList<MyMoneyStatement::Security> m_securitylist;
@@ -81,9 +90,28 @@ public:
   Wallet *m_wallet;
   QDate m_updateStartDate;
   int m_timestampOffset;
+  QSet<QString> m_hashes;
+
+  int constructTimeOffset(const QTimeEdit* timestampOffset, const KComboBox* timestampOffsetSign) const
+  {
+    // get offset in minutes
+    int offset = timestampOffset->time().msecsSinceStartOfDay() / 1000 / 60;
+    if (timestampOffsetSign->currentText() == QStringLiteral("-")) {
+      offset = -offset;
+    }
+    return offset;
+  }
+
 };
 
 
+static UniqueTransactionIdSource defaultIdSource()
+{
+  KSharedConfigPtr config = KSharedConfig::openConfig(QStringLiteral("kmymoney/ofximporterrc"));
+  KConfigGroup grp = config->group("General");
+
+  return (grp.readEntry<bool>("useOwnFITID", false) == true) ? UniqueIdKMyMoney : UniqueIdOfx;
+}
 
 
 OFXImporter::OFXImporter(QObject *parent, const QVariantList &args) :
@@ -126,6 +154,9 @@ void OFXImporter::slotImportFile()
   Ui_ImportOption* option = new Ui_ImportOption;
   option->setupUi(widget);
 
+  // initially set to global default option
+  option->m_uniqueIdSource->setCurrentIndex(defaultIdSource());
+
   QUrl url = importInterface()->selectFile(i18n("OFX import file selection"),
              QString(),
              QStringLiteral("*.ofx *.qfx *.ofc|OFX files (*.ofx *.qfx *.ofc);;*|All files (*)"),
@@ -133,6 +164,8 @@ void OFXImporter::slotImportFile()
              widget);
 
   d->m_preferName = static_cast<OFXImporter::Private::NamePreference>(option->m_preferName->currentIndex());
+  d->m_uniqueIdSource = static_cast<UniqueTransactionIdSource>(option->m_uniqueIdSource->currentIndex());
+  d->m_timestampOffset = d->constructTimeOffset(option->m_timestampOffset, option->m_timestampOffsetSign);
 
   if (url.isValid()) {
     const QString filename(url.toLocalFile());
@@ -225,6 +258,8 @@ bool OFXImporter::import(const QString& filename)
   // This has no setter (see libofx.h)
   ofx_show_position = false;
 
+  d->m_hashes.clear();
+
   qDebug("setup callback routines");
   ofx_set_transaction_cb(ctx, ofxTransactionCallback, this);
   ofx_set_statement_cb(ctx, ofxStatementCallback, this);
@@ -292,10 +327,53 @@ int OFXImporter::ofxTransactionCallback(struct OfxTransactionData data, void * p
     t.m_strNumber = QString::fromUtf8(data.check_number);
   }
 
-  if (data.fi_id_valid) {
-    t.m_strBankID = QStringLiteral("ID ") + QString::fromUtf8(data.fi_id);
-  } else if (data.reference_number_valid) {
-    t.m_strBankID = QStringLiteral("REF ") + QString::fromUtf8(data.reference_number);
+  unsigned long h;
+  QString tmpString;
+  // in case the unique transaction id source is yet unknown we
+  // use the global preset
+  UniqueTransactionIdSource idSource = pofx->d->m_uniqueIdSource;
+  if (idSource == UniqueIdUnknown) {
+    idSource = defaultIdSource();
+  }
+  switch (idSource) {
+    default:
+    case UniqueIdOfx:
+      if (data.fi_id_valid) {
+        t.m_strBankID = QStringLiteral("ID ") + QString::fromUtf8(data.fi_id);
+      } else if (data.reference_number_valid) {
+        t.m_strBankID = QStringLiteral("REF ") + QString::fromUtf8(data.reference_number);
+      }
+      break;
+
+    case UniqueIdKMyMoney:
+      if (data.payee_id_valid) {
+        tmpString = QString::fromUtf8(data.payee_id);
+      } else if (data.name_valid) {
+        tmpString = QString::fromUtf8(data.name);
+      } else if (data.memo_valid) {
+        tmpString = QString::fromUtf8(data.memo);
+      }
+      h = MyMoneyTransaction::hash(tmpString.trimmed());
+      if (data.memo_valid)
+        h = MyMoneyTransaction::hash(QString::fromUtf8(data.memo), h);
+
+      h = MyMoneyTransaction::hash(t.m_amount.toString(), h);
+      // make hash value unique in case we don't have one already
+
+      QString hashBase;
+      hashBase.sprintf("%s-%07lx", qPrintable(t.m_datePosted.toString(Qt::ISODate)), h);
+      int idx = 1;
+      QString hash;
+      for (;;) {
+        hash = QString("%1-%2").arg(hashBase).arg(idx);
+        if (!pofx->d->m_hashes.contains(hash)) {
+          pofx->d->m_hashes += hash;
+          break;
+        }
+        ++idx;
+      }
+      t.m_strBankID = QString("KMM %1").arg(hash);
+      break;
   }
 
   // Decide whether to use NAME, PAYEEID or MEMO to construct the payee
@@ -543,6 +621,8 @@ int OFXImporter::ofxAccountCallback(struct OfxAccountData data, void * pv)
 
   // Having any account at all makes an ofx statement valid
   pofx->d->m_valid = true;
+  // new account means new hashes
+  pofx->d->m_hashes.clear();
 
   if (data.account_id_valid) {
     s.m_strAccountName = QString::fromUtf8(data.account_name);
@@ -715,18 +795,15 @@ MyMoneyKeyValueContainer OFXImporter::onlineBankingSettings(const MyMoneyKeyValu
     kvp.setValue(QStringLiteral("kmmofx-pickDate"), QString::number(d->m_statusDlg->m_pickDateRB->isChecked()));
     kvp.setValue(QStringLiteral("kmmofx-specificDate"), d->m_statusDlg->m_specificDate->date().toString());
     kvp.setValue(QStringLiteral("kmmofx-preferName"), QString::number(d->m_statusDlg->m_preferredPayee->currentIndex()));
+    kvp.setValue(QStringLiteral("kmmofx-uniqueIdSource"), QString::number(d->m_statusDlg->m_uniqueTransactionId->currentIndex()));
     if (!d->m_statusDlg->m_clientUidEdit->text().isEmpty())
       kvp.setValue(QStringLiteral("clientUid"), d->m_statusDlg->m_clientUidEdit->text());
     else
       kvp.deletePair(QStringLiteral("clientUid"));
-    if (d->m_statusDlg->m_timestampOffset->time().msecsSinceStartOfDay() == 0) {
+    int offset = d->constructTimeOffset(d->m_statusDlg->m_timestampOffset, d->m_statusDlg->m_timestampOffsetSign);
+    if (offset == 0) {
       kvp.deletePair(QStringLiteral("kmmofx-timestampOffset"));
     } else {
-      // get offset in minutes
-      int offset = d->m_statusDlg->m_timestampOffset->time().msecsSinceStartOfDay() / 1000 / 60;
-      if (d->m_statusDlg->m_timestampOffsetSign->currentText() == QStringLiteral("-")) {
-        offset = -offset;
-      }
       kvp.setValue(QStringLiteral("kmmofx-timestampOffset"), QString::number(offset));
     }
     // get rid of pre 4.6 values
@@ -758,9 +835,14 @@ bool OFXImporter::updateAccount(const MyMoneyAccount& acc, bool moreAccounts)
 
   qDebug("OfxImporterPlugin::updateAccount");
   try {
+    d->m_uniqueIdSource = UniqueIdUnknown;
     if (!acc.id().isEmpty()) {
       // Save the value of preferName to be used by ofxTransactionCallback
       d->m_preferName = static_cast<OFXImporter::Private::NamePreference>(acc.onlineBankingSettings().value(QStringLiteral("kmmofx-preferName")).toInt());
+      if (acc.onlineBankingSettings().value(QStringLiteral("kmmofx-uniqueIdSource")).isEmpty())
+        d->m_uniqueIdSource = defaultIdSource();
+      else
+        d->m_uniqueIdSource = static_cast<UniqueTransactionIdSource>(acc.onlineBankingSettings().value(QStringLiteral("kmmofx-uniqueIdSource")).toInt());
       QPointer<KOfxDirectConnectDlg> dlg = new KOfxDirectConnectDlg(acc);
 
       connect(dlg.data(), &KOfxDirectConnectDlg::statementReady, this, static_cast<void (OFXImporter::*)(const QString &)>(&OFXImporter::slotImportFile));
